@@ -25,10 +25,7 @@ from pecan.templating import (
 from pecan.decorators import accept_noncanonical
 from pecan.tests import PecanTestCase
 
-if sys.version_info < (2, 7):
-    import unittest2 as unittest  # pragma: nocover
-else:
-    import unittest  # pragma: nocover
+import unittest
 
 
 class SampleRootController(object):
@@ -339,11 +336,20 @@ class TestLookups(PecanTestCase):
             def _lookup(self, someID):
                 return 'Bad arg spec'  # pragma: nocover
 
-        with warnings.catch_warnings():
-            warnings.simplefilter("ignore")
-            app = TestApp(Pecan(RootController()))
-            r = app.get('/foo/bar', expect_errors=True)
-            assert r.status_int == 404
+        app = TestApp(Pecan(RootController()))
+        r = app.get('/foo/bar', expect_errors=True)
+        assert r.status_int == 404
+
+    def test_lookup_with_wrong_return(self):
+        class RootController(object):
+            @expose()
+            def _lookup(self, someID, *remainder):
+                return 1
+
+        app = TestApp(Pecan(RootController()))
+        self.assertRaises(TypeError,
+                          app.get,
+                          '/foo/bar', expect_errors=True)
 
 
 class TestCanonicalLookups(PecanTestCase):
@@ -1523,6 +1529,13 @@ class TestContentTypeByAcceptHeaders(PecanTestCase):
 
         return TestApp(Pecan(RootController()))
 
+    def test_missing_accept(self):
+        r = self.app_.get('/', headers={
+            'Accept': ''
+        })
+        assert r.status_int == 200
+        assert r.content_type == 'text/html'
+
     def test_quality(self):
         r = self.app_.get('/', headers={
             'Accept': 'text/html,application/json;q=0.9,*/*;q=0.8'
@@ -1916,11 +1929,6 @@ class TestEngines(PecanTestCase):
         assert 'support for "mako3" was not found;' in str(expected)
 
     def test_json(self):
-        try:
-            from simplejson import loads
-        except:
-            from json import loads  # noqa
-
         expected_result = dict(
             name='Jonathan',
             age=30, nested=dict(works=True)
@@ -1934,7 +1942,7 @@ class TestEngines(PecanTestCase):
         app = TestApp(Pecan(RootController()))
         r = app.get('/')
         assert r.status_int == 200
-        result = dict(loads(r.body.decode()))
+        result = json.loads(r.body.decode())
         assert result == expected_result
 
     def test_custom_renderer(self):
